@echo off
rem -------------------------------------------------------------------------
rem JBoss Bootstrap Script for Windows
rem -------------------------------------------------------------------------

rem Use --debug to activate debug mode with an optional argument to specify the port
rem Usage : standalone.bat --debug
rem         standalone.bat --debug 9797

@if not "%ECHO%" == ""  echo %ECHO%
@if "%OS%" == "Windows_NT" setlocal

rem By default debug mode is disable.
set DEBUG_MODE=false
set DEBUG_PORT=8787
rem Set to all parameters by default
set "SERVER_OPTS=%*"

if NOT "x%DEBUG%" == "x" (
  set "DEBUG_MODE=%DEBUG%
)

rem Get the program name before using shift as the command modify the variable ~nx0
if "%OS%" == "Windows_NT" (
  set "PROGNAME=%~nx0%"
) else (
  set "PROGNAME=standalone.bat"
)

if "%OS%" == "Windows_NT" (
  set "DIRNAME=%~dp0%"
) else (
  set DIRNAME=.\
)
setlocal EnableDelayedExpansion
rem check for the security manager system property
echo(!SERVER_OPTS! | findstr /r /c:"-Djava.security.manager" > nul
if not errorlevel == 1 (
    echo ERROR: The use of -Djava.security.manager has been removed. Please use the -secmgr command line argument or SECMGR=true environment variable.
    GOTO :EOF
)
setlocal DisableDelayedExpansion

rem Read command-line args, the ~ removes the quotes from the parameter
:READ-ARGS
if "%~1" == "" (
   goto MAIN
) else if "%~1" == "--debug" (
   goto READ-DEBUG-PORT
) else if "%~1" == "-secmgr" (
   set SECMGR=true
)
shift
goto READ-ARGS

:READ-DEBUG-PORT
set "DEBUG_MODE=true"
set DEBUG_ARG="%2"
if not %DEBUG_ARG% == "" (
   if x%DEBUG_ARG:-=%==x%DEBUG_ARG% (
      shift
      set DEBUG_PORT=%DEBUG_ARG%
   )
   shift
   goto READ-ARGS
)

:MAIN
rem $Id$
)

pushd "%DIRNAME%.."
set "RESOLVED_JBOSS_HOME=%CD%"
popd

if "x%JBOSS_HOME%" == "x" (
  set "JBOSS_HOME=%RESOLVED_JBOSS_HOME%"
)

pushd %DIRNAME%..\..\..
if "x%NETAPP_HOME%" == "x" (
    set "NETAPP_HOME=%CD%"
)
popd

pushd "%JBOSS_HOME%"
set "SANITIZED_JBOSS_HOME=%CD%"
popd

if /i "%RESOLVED_JBOSS_HOME%" NEQ "%SANITIZED_JBOSS_HOME%" (
   echo.
   echo   WARNING:  JBOSS_HOME may be pointing to a different installation - unpredictable results may occur.
   echo.
   echo       JBOSS_HOME: "%JBOSS_HOME%"
   echo.
)

rem setting memory parameters for services
if "x%ADJUST_MEM_CONFIG%" == "x" (
	set "ADJUST_MEM_CONFIG=%NETAPP_HOME%\ocum\bin\adjust_mem_cfg.ps1"
)

if exist "%ADJUST_MEM_CONFIG%" (
SETLOCAL ENABLEDELAYEDEXPANSION
	powershell -executionpolicy remotesigned -File "!ADJUST_MEM_CONFIG!"
	if "x!errorlevel!" == "x-1" (
		 taskkill /f /im mysqld.exe
		 exit 666
	)
	SETLOCAL DISABLEDELAYEDEXPANSION
)

rem Read an optional configuration file.
if "x%STANDALONE_CONF%" == "x" (
   set "STANDALONE_CONF=%DIRNAME%standalone.conf.bat"
)
if exist "%STANDALONE_CONF%" (
   echo Calling "%STANDALONE_CONF%"
   call "%STANDALONE_CONF%" %*
) else (
   echo Config file not found "%STANDALONE_CONF%"
)

:: ###############################################################################
:: ## Added by NetApp
:: ## Description: In order to make the least amount of changes to this file
:: ##              we want to externalize all of the changes required by our 
:: ##              applications.  Todo this, we will create a new conf directory
:: ##              located at:
:: ##                 %DIRNAME%/conf/*.bat
:: ##             
:: ##              This will read in those files and source them based on 
:: ##              directory listing (ls -dv)

:: Set Java PATH by getting javahome from javaasoft key

set javasoftkey="HKEY_LOCAL_MACHINE\SOFTWARE\JavaSoft\Java Runtime Environment\1.8"
set value="javaHome"
for /f  "usebackq tokens=2*" %%a in (`reg query %javasoftkey% /v %value% /reg:64 2^>nul`) do (
	set javahome=%%b
)

if NOT "x%javahome%" == "x" (
	set "JAVA=%javahome%\bin\java.exe"
)

IF EXIST "%JAVA%" (
	echo "Found file %JAVA%"
) else (
	echo "Could not find %JAVA%"
	if not exist "%JAVA_HOME%" (
		echo JAVA_HOME "%JAVA_HOME%" path doesn't exist
		ECHO "EXIT"
	) else (
		echo Setting JAVA property to "%JAVA_HOME%\bin\java"
		set "JAVA=%JAVA_HOME%\bin\java"
		ECHO "%JAVA%"
	)
)

set EXTERNAL_CONFIG_DIR=%DIRNAME%\conf
if exist "%EXTERNAL_CONFIG_DIR%" (
    setlocal EnableDelayedExpansion
    set "output_cnt=0"
    :: Get all of the contents of the directory in legacy order
    for /F "delims=" %%f in ('dir /B /O:N %EXTERNAL_CONFIG_DIR%\*.bat') do (
        set /a output_cnt+=1
        set "output[!output_cnt!]=%%f"
    )
    :: Now source all of them.
    for /L %%n in (1 1 !output_cnt!) do (
        echo "Pulling in !output[%%n]! for setup"
        call "%EXTERNAL_CONFIG_DIR%\!output[%%n]!"
    )
)
:: ## End NetApp changes
:: ###############################################################################


rem Set debug settings if not already set
if "%DEBUG_MODE%" == "true" (
   echo "%JAVA_OPTS%" | findstr /I "\-agentlib:jdwp" > nul
  if errorlevel == 1 (
     set "JAVA_OPTS=%JAVA_OPTS% -agentlib:jdwp=transport=dt_socket,address=%DEBUG_PORT%,server=y,suspend=n"
  ) else (
     echo Debug already enabled in JAVA_OPTS, ignoring --debug argument
  )
)

set DIRNAME=

:: *******************************************************************************
:: NetApp Added 
::
:: DO NOT USE THE PART BELOW IF SOME USER-DEFINED PATH HAS SPACES
:: TO GET THE SAME FUNCTIONALITY WITHOUT USING SPACE AS DELIMITER FOR PARSING TOKEN,
:: WE CAN DIRECTLY SET THE VARIABLES JBOSS_BASE_DIR, JBOSS_CONFIG_DIR, JBOSS_LOG_DIR
:: BASED ON CUSTOMIZED VALUES OF jboss.server.*.dir

rem Setup JBoss specific properties

rem Setup directories, note directories with spaces do not work
rem set "CONSOLIDATED_OPTS=%JAVA_OPTS% %SERVER_OPTS%"

rem :DIRLOOP
rem echo(%CONSOLIDATED_OPTS% | findstr /r /c:"^-Djboss.server.base.dir" > nul && (
rem  for /f "tokens=1,2* delims==" %%a IN ("%CONSOLIDATED_OPTS%") DO (
rem     for /f %%i IN ("%%b") DO set "JBOSS_BASE_DIR=%%~fi"
rem  )
rem )
rem echo(%CONSOLIDATED_OPTS% | findstr /r /c:"^-Djboss.server.config.dir" > nul && (
rem   for /f "tokens=1,2* delims==" %%a IN ("%CONSOLIDATED_OPTS%") DO (
rem    for /f %%i IN ("%%b") DO set "JBOSS_CONFIG_DIR=%%~fi"
rem  )
rem )
rem echo(%CONSOLIDATED_OPTS% | findstr /r /c:"^-Djboss.server.log.dir" > nul && (
rem for /f "tokens=1,2* delims==" %%a IN ("%CONSOLIDATED_OPTS%") DO (
rem    for /f %%i IN ("%%b") DO set "JBOSS_LOG_DIR=%%~fi"
rem  )
rem )

rem for /f "tokens=1* delims= " %%i IN ("%CONSOLIDATED_OPTS%") DO (
rem  if %%i == "" (
rem    goto ENDDIRLOOP
rem  ) else (
rem    set CONSOLIDATED_OPTS=%%j
rem    GOTO DIRLOOP
rem  )
rem )
:: *******************************************************************************

rem :ENDDIRLOOP

rem Set default module root paths
if "x%JBOSS_MODULEPATH%" == "x" (
  set  "JBOSS_MODULEPATH=%JBOSS_HOME%\modules"
)

rem Set the standalone base dir
if "x%JBOSS_BASE_DIR%" == "x" (
  set  "JBOSS_BASE_DIR=%JBOSS_HOME%\standalone"
)
rem Set the standalone log dir
if "x%JBOSS_LOG_DIR%" == "x" (
  set  "JBOSS_LOG_DIR=%JBOSS_BASE_DIR%\log"
)
rem Set the standalone configuration dir
if "x%JBOSS_CONFIG_DIR%" == "x" (
  set  "JBOSS_CONFIG_DIR=%JBOSS_BASE_DIR%\configuration"
)

rem Setup JBoss specific properties
set "JAVA_OPTS=-Dprogram.name=%PROGNAME% %JAVA_OPTS%"

:: NetApp Change. Commented the below lines since java path is set above. 
:: -- From Here
::if "x%JAVA_HOME%" == "x" (
::  set  JAVA=java
::  echo JAVA_HOME is not set. Unexpected results may occur.
::  echo Set JAVA_HOME to the directory of your local JDK to avoid this message.
::) else (
::  if not exist "%JAVA_HOME%" (
::    echo JAVA_HOME "%JAVA_HOME%" path doesn't exist
::    goto END
::  ) else (
::    echo Setting JAVA property to "%JAVA_HOME%\bin\java"
::    set "JAVA=%JAVA_HOME%\bin\java"
::  )
::)
:: -- Till here

if not "%PRESERVE_JAVA_OPTS%" == "true" (
  rem Add -client to the JVM options, if supported (32 bit VM), and not overriden
  echo "%JAVA_OPTS%" | findstr /I \-server > nul
  if errorlevel == 1 (
    "%JAVA%" -client -version 2>&1 | findstr /I /C:"Client VM" > nul
    if not errorlevel == 1 (
      set "JAVA_OPTS=-client %JAVA_OPTS%"
    )
  )
)

rem EAP6-121 feature disabled
rem if not "%PRESERVE_JAVA_OPTS%" == "true" (
  rem Add rotating GC logs, if supported, and not already defined
  rem echo "%JAVA_OPTS%" | findstr /I "\-verbose:gc" > nul
  rem if errorlevel == 1 (
    rem Back up any prior logs
    rem move /y "%JBOSS_LOG_DIR%\gc.log.0" "%JBOSS_LOG_DIR%\backupgc.log.0" > nul 2>&1
    rem move /y "%JBOSS_LOG_DIR%\gc.log.1" "%JBOSS_LOG_DIR%\backupgc.log.1" > nul 2>&1
    rem move /y "%JBOSS_LOG_DIR%\gc.log.2" "%JBOSS_LOG_DIR%\backupgc.log.2" > nul 2>&1
    rem move /y "%JBOSS_LOG_DIR%\gc.log.3" "%JBOSS_LOG_DIR%\backupgc.log.3" > nul 2>&1
    rem move /y "%JBOSS_LOG_DIR%\gc.log.4" "%JBOSS_LOG_DIR%\backupgc.log.4" > nul 2>&1
    rem move /y "%JBOSS_LOG_DIR%\gc.log.*.current" "%JBOSS_LOG_DIR%\backupgc.log.current" > nul 2>&1
    rem "%JAVA%" -verbose:gc -XX:+PrintGCDetails -XX:+PrintGCDateStamps -XX:+UseGCLogFileRotation -XX:NumberOfGCLogFiles=5 -XX:GCLogFileSize=3M -Xloggc:%XLOGGC% -XX:-TraceClassUnloading -version > nul 2>&1
    rem if not errorlevel == 1 (
      rem if not exist "%JBOSS_LOG_DIR" > nul 2>&1 (
        rem mkdir "%JBOSS_LOG_DIR%"
      rem )
     rem set XLOGGC="%JBOSS_LOG_DIR%\gc.log"
     rem set "JAVA_OPTS=-verbose:gc -XX:+PrintGCDetails -XX:+PrintGCDateStamps -XX:+UseGCLogFileRotation -XX:NumberOfGCLogFiles=5 -XX:GCLogFileSize=3M -XX:-TraceClassUnloading %JAVA_OPTS%"
    rem )
  rem )
rem )

rem Find jboss-modules.jar, or we can't continue
if exist "%JBOSS_HOME%\jboss-modules.jar" (
    set "RUNJAR=%JBOSS_HOME%\jboss-modules.jar"
) else (
  echo Could not locate "%JBOSS_HOME%\jboss-modules.jar".
  echo Please check that you are in the bin directory when running this script.
  goto END
)

rem Setup JBoss specific properties

rem Setup directories, note directories with spaces do not work
setlocal EnableDelayedExpansion
set "CONSOLIDATED_OPTS=%JAVA_OPTS% %SERVER_OPTS%"
set baseDirFound=false
set configDirFound=false
set logDirFound=false
for %%a in (!CONSOLIDATED_OPTS!) do (
   if !baseDirFound! == true (
      set "JBOSS_BASE_DIR=%%~a"
      set baseDirFound=false
   )
   if !configDirFound! == true (
      set "JBOSS_CONFIG_DIR=%%~a"
      set configDirFound=false
   )
   if !logDirFound! == true (
      set "JBOSS_LOG_DIR=%%~a"
      set logDirFound=false
   )
   if "%%~a" == "-Djboss.server.base.dir" (
       set baseDirFound=true
   )
   if "%%~a" == "-Djboss.server.config.dir" (
       set configDirFound=true
   )
   if "%%~a" == "-Djboss.server.log.dir" (
       set logDirFound=true
   )
)

rem If the -Djava.security.manager is found, enable the -secmgr and include a bogus security manager for JBoss Modules to replace
echo(!JAVA_OPTS! | findstr /r /c:"-Djava.security.manager" > nul && (
    echo ERROR: The use of -Djava.security.manager has been removed. Please use the -secmgr command line argument or SECMGR=true environment variable.
    GOTO :EOF
)
setlocal DisableDelayedExpansion

rem Set default module root paths
if "x%JBOSS_MODULEPATH%" == "x" (
  set  "JBOSS_MODULEPATH=%JBOSS_HOME%\modules"
)

rem Set the standalone base dir
if "x%JBOSS_BASE_DIR%" == "x" (
  set  "JBOSS_BASE_DIR=%JBOSS_HOME%\standalone"
)
rem Set the standalone log dir
if "x%JBOSS_LOG_DIR%" == "x" (
  set  "JBOSS_LOG_DIR=%JBOSS_BASE_DIR%\log"
)
rem Set the standalone configuration dir
if "x%JBOSS_CONFIG_DIR%" == "x" (
  set  "JBOSS_CONFIG_DIR=%JBOSS_BASE_DIR%\configuration"
)

rem Set the module options
set "MODULE_OPTS="
if "%SECMGR%" == "true" (
    set "MODULE_OPTS=-secmgr"
)

rem NetApp - Need this for the windows authentication.
set JAVA_OPTS=%JAVA_OPTS% -Djava.library.path="%PLATFORM_HOME%\jboss\bin\native\lib64" -Dprogram.name=%PROGNAME% -Donaro.home="%PLATFORM_HOME%"

echo ===============================================================================
echo.
echo   JBoss Bootstrap Environment
echo.
echo   JBOSS_HOME: "%JBOSS_HOME%"
echo.
echo   JAVA: "%JAVA%"
echo.
echo   JAVA_OPTS: "%JAVA_OPTS%"
echo.
echo ===============================================================================
echo.

:RESTART
rem if x%XLOGGC% == x (
  "%JAVA%" %JAVA_OPTS% ^
   "-Dorg.jboss.boot.log.file=%JBOSS_LOG_DIR%\server.log" ^
   "-Dlogging.configuration=file:%JBOSS_CONFIG_DIR%\logging.properties" ^
      -jar "%JBOSS_HOME%\jboss-modules.jar" ^
      %MODULE_OPTS% ^
      -mp "%JBOSS_MODULEPATH%" ^
      -jaxpmodule "javax.xml.jaxp-provider" ^
       org.jboss.as.standalone ^
      "-Djboss.home.dir=%JBOSS_HOME%" ^
	  "-Djboss.server.base.dir=%JBOSS_BASE_DIR%" ^
       %SERVER_OPTS%
rem ) else (
  rem "%JAVA%" -Xloggc:%XLOGGC% %JAVA_OPTS% ^
   rem "-Dorg.jboss.boot.log.file=%JBOSS_LOG_DIR%\server.log" ^
   rem "-Dlogging.configuration=file:%JBOSS_CONFIG_DIR%/logging.properties" ^
      rem -jar "%JBOSS_HOME%\jboss-modules.jar" ^
      rem %MODULE_OPTS% ^
      rem -mp "%JBOSS_MODULEPATH%" ^
      rem org.jboss.as.standalone ^
      rem "-Djboss.home.dir=%JBOSS_HOME%" ^
      rem %SERVER_OPTS%
rem )

if ERRORLEVEL 10 goto RESTART

:END
if "x%NOPAUSE%" == "x" pause

:END_NO_PAUSE
